#ifndef __SOUND_H__
#define __SOUND_H__

#define SND_CLICK	0
#define SND_SWAP	1

extern int snd_init(void);
extern void snd_done(void);
extern void snd_play(int sample, int cnt);
extern int snd_music_start(void);
extern void snd_music_stop(void);
extern void snd_volume(int vol);
extern int g_music_on;
extern int g_sound_on;

#endif
